@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2017 by Dominique Dumont.
+# This software is Copyright (c) 2008-2019 by Dominique Dumont <ddumont@cpan.org>.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Tk::HashEditor;
-$Config::Model::Tk::HashEditor::VERSION = '1.365';
+package Config::Model::Tk::HashEditor 1.370;
+
 use strict;
 use warnings;
 use Carp;
@@ -20,6 +20,7 @@ use subs qw/menu_struct/;
 use Tk::Dialog;
 use Tk::Photo;
 use Tk::Balloon;
+use List::MoreUtils qw/apply/;
 use Config::Model::Tk::NoteEditor;
 
 Construct Tk::Widget 'ConfigModelHashEditor';
@@ -31,7 +32,7 @@ my $logger = Log::Log4perl::get_logger("Tk::HashEditor");
 
 my $entry_width = 15;
 
-my ( $up_img, $down_img, $add_img, $rm_img, $eraser_img, $remove_img, $rename_img, $copy_img );
+my ( $up_img, $down_img, $add_img, $eraser_img, $remove_img, $rename_img, $copy_img );
 *icon_path = *Config::Model::TkUI::icon_path;
 
 sub ClassInit {
@@ -250,16 +251,14 @@ sub reset_value {
 sub insert {
     my $cw = shift ;
     my $where = shift ;
-    my @what = map { s/\n/\\n/g; $_; }
-        #map { $hash->shorten_idx($_); }
-        @_ ;
+    my @what = apply { s/\n/\\n/g; $_; } @_ ;
     $cw->Subwidget('tklist')->insert($where => @what);
 }
 
 # this function (not a method) restore the LF in a multi line key
 # (reverse the operation done above
 sub restore_keys {
-    return map { s/\\n/\n/g; $_; } @_ ;
+    return apply { s/\\n/\n/g; $_; } @_ ;
 }
 
 sub remove_all_elements {
